#ifndef QT_FEATURES_WebEngineQuick_src_webenginequick_qtwebenginequick_config_p_h_H
#define QT_FEATURES_WebEngineQuick_src_webenginequick_qtwebenginequick_config_p_h_H

#define QT_FEATURE_webenginequick_ui_delegates 1


#endif // QT_FEATURES_WebEngineQuick_src_webenginequick_qtwebenginequick_config_p_h_H
