/* This file was generated by syncqt. */
#ifndef QT_QTWEBENGINECORE_VERSION_H
#define QT_QTWEBENGINECORE_VERSION_H

#define QTWEBENGINECORE_VERSION_STR "6.11.0"

#define QTWEBENGINECORE_VERSION 0x0601100

#endif // QT_QTWEBENGINECORE_VERSION_H
