#ifndef QT_FEATURES_WebEngineCore_src_core_api_qtwebenginecore_config_h_H
#define QT_FEATURES_WebEngineCore_src_core_api_qtwebenginecore_config_h_H

#define QT_FEATURE_webengine_geolocation 1

#define QT_FEATURE_webengine_webchannel 1

#define QT_FEATURE_webengine_spellchecker 1

#define QT_FEATURE_webengine_native_spellchecker -1

#define QT_FEATURE_webengine_extensions 1

#define QT_FEATURE_webenginedriver 1


#endif // QT_FEATURES_WebEngineCore_src_core_api_qtwebenginecore_config_h_H
